@@ -1,3 +1,7 @@
+//! See the [readme](https://github.com/johanhelsing/bevy_smud) and
+//! [examples](https://github.com/johanhelsing/bevy_smud/tree/main/examples) for
+//! usage.
+
 use std::cmp::Ordering;
 
 use bevy::{
@@ -49,6 +53,12 @@ mod sdf_assets;
 mod shader_loading;
 mod ui;
 
+/// Re-export of the essentials needed for rendering shapes
+///
+/// Intended to be included at the top of your file to minimize the amount of import noise.
+/// ```
+/// use bevy_smud::prelude::*;
+/// ```
 pub mod prelude {
     pub use crate::{
         sdf_assets::SdfAssets, Frame, ShapeBundle, SmudPlugin, SmudShape, UiShapeBundle,
@@ -57,6 +67,7 @@ pub mod prelude {
 }
 
 #[derive(Default)]
+/// Main plugin for enabling rendering of Sdf shapes
 pub struct SmudPlugin;
 
 impl Plugin for SmudPlugin {
@@ -254,8 +265,7 @@ impl SpecializedPipeline for SmudPipeline {
 
         RenderPipelineDescriptor {
             vertex: VertexState {
-                shader: shader.clone_weak(),
-                // shader: SMUD_SHADER_HANDLE.typed::<Shader>(),
+                shader: VERTEX_SHADER_HANDLE.typed(),
                 entry_point: "vertex".into(),
                 shader_defs: Vec::new(),
                 buffers: vec![VertexBufferLayout {
@@ -351,7 +361,6 @@ fn extract_sdf_shaders(
         info!("Generating shader");
         let generated_shader = Shader::from_wgsl(format!(
             r#"
-#import bevy_smud::vertex
 #import {sdf_import_path}
 #import {fill_import_path}
 #import bevy_smud::fragment
